==> haskell-regex-applicative-0.3.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative
version: 0.3.3
id: regex-applicative-0.3.3-J7A66V0KzYR10wjnSp8bVc
key: regex-applicative-0.3.3-J7A66V0KzYR10wjnSp8bVc
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/regex-applicative
synopsis: Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.
category: Text
author: Roman Cheplyaka
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue
hidden-modules: Text.Regex.Applicative.Interface
                Text.Regex.Applicative.Types Text.Regex.Applicative.Compile
abi: 0e2d88138bd55ac2d976f1831af13753
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/regex-applicative-0.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/regex-applicative-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/regex-applicative-0.3.3
hs-libraries: HSregex-applicative-0.3.3-J7A66V0KzYR10wjnSp8bVc
depends:
    base-4.10.0.0 containers-0.5.10.2 transformers-0.5.2.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
haddock-interfaces: /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-0.3.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative
version: 0.3.3
id: regex-applicative-0.3.3-DxcXiGFOKNJAEyOISHX5JB
key: regex-applicative-0.3.3-DxcXiGFOKNJAEyOISHX5JB
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/regex-applicative
synopsis: Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.
category: Text
author: Roman Cheplyaka
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue
hidden-modules: Text.Regex.Applicative.Interface
                Text.Regex.Applicative.Types Text.Regex.Applicative.Compile
abi: 122463352fd3d35c41b65641e1bba1e1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-applicative-0.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-applicative-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/regex-applicative-0.3.3
hs-libraries: HSregex-applicative-0.3.3-DxcXiGFOKNJAEyOISHX5JB
depends:
    base-4.10.1.0 containers-0.5.10.2 transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
